<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">

<!-- Localised settings for numbers -->
<xsl:decimal-format name="en" decimal-separator="." grouping-separator="," NaN="&#60;Null&#62;"/>
<xsl:decimal-format name="de" decimal-separator="," grouping-separator="." NaN="&#60;Null&#62;"/>

<!-- Reference to the external document with all data -->
<xsl:variable name="EPANET" select="document('EPANETModel.xml')"/>

<!-- Index on results for faster lookup -->
<xsl:key name="ResultKey" match="Group[@Name='mw_RESNode']/Rows/R" use="@MUID"/>

<xsl:template match="/">
	<html>
		<head>
			<title>Ergebnisse in Knoten</title>
			<!-- Reference to the external stripes script -->
			<script src="stripes.js" type="text/javascript">
			</script>
		</head>

		<!-- Reference to the external style sheet -->
		<link rel="stylesheet" type="text/css"  href="default.css"/>

		<!-- Colour for uneven rows and for even rows -->
		<body onload="stripe('tabelle', '#ffffff', '#96c3e3')">
		
			<div id="firmablock">
				<xsl:for-each select="document('Unternehmen.xml')/name/zeile">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</div>
			
			<div id="projektblock">
				<xsl:for-each select="document('Projekt.xml')/titel/zeile">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</div>

			<h1>Ergebnisse in Knoten</h1>

			<table id="tabelle" border="0" cellpadding="0" cellspacing="0" summary="">

			<!-- Custom text, e.g. company name, project name
			     In order to make custom text visible, remove: display:none  -->
			<caption style="text-align:left; display:none">Custom Text</caption>

			<colgroup>
				<!--  Column width and column alignment -->
				<col width="90px" />	<!-- Knoten ID -->
				<col width="90px"  style="text-align: right;"/>	<!-- Knotenhhe -->
				<col width="90px" style="text-align: right;"/>	<!-- Druck max -->
				<col width="90px" style="text-align: right;"/>	<!-- Druckhhe max -->
			</colgroup>

			<thead>
				<tr>
					<!-- Column headers with units -->
					<xsl:for-each select="$EPANET/mu">
					<th>
						Knoten ID<br />
					</th>
					<th>
						Knoten-<br />
						hhe<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_Junction']/Metadata/Field[@Name='Elev']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Druck<br />
						<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_RESNode']/Metadata/Field[@Name='Pressure_Max']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Druckhhe<br />
						<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Group[@Name='mw_RESNode']/Metadata/Field[@Name='Grade_Max']/@Unit"/></xsl:call-template>
					</th>

					</xsl:for-each>
				</tr>
			</thead>

			<xsl:for-each select="$EPANET/mu/Group[@Name='mw_Junction']/Rows/R">
				<xsl:sort select="@MUID"/>
				<tr>
					<!-- Data within each row including number format -->
					<td><xsl:value-of select="@MUID"/></td>
					<td><xsl:value-of select="format-number(@Elev,'#.##0,00','de')"/></td>
					<td><xsl:value-of select="format-number(key('ResultKey',@MUID)/@Pressure_Max,'#.##0,00','de')"/></td>
					<td><xsl:value-of select="format-number(key('ResultKey',@MUID)/@Grade_Max,'#.##0,00','de')"/></td>
				</tr>
			</xsl:for-each>
			</table>

			<!-- Some comment
			     In order to make custom text visible, remove: display:none -->
			<p style="font-size: 9pt; margin-top: 5px; display:none;">Comment</p>

		</body>
	</html>

</xsl:template>

<!-- Lookup table for unit abbreviations -->
<xsl:template name="ChooseUnitAbbr">
	<xsl:param name="UnitString"/>
	<xsl:choose>
		<!-- Length -->
		<xsl:when test="$UnitString = 'CentiMeter'"><xsl:text>[cm]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Feet'"><xsl:text>[ft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Inch'"><xsl:text>[in]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloMeter'"><xsl:text>[km]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Meter'"><xsl:text>[m]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Mile'"><xsl:text>[mi]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliFeet'"><xsl:text>[mft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeter'"><xsl:text>[mm]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Yard'"><xsl:text>[yd]</xsl:text></xsl:when>
		<!--  Pressure -->
		<xsl:when test="$UnitString = 'Bar'"><xsl:text>[bar]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'FeetOfWater'"><xsl:text>[ft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'HectoPascal'"><xsl:text>[hPa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloNewtonPerSquareMeter'"><xsl:text>[kN/m2]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloPascal'"><xsl:text>[kPa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MegaPascal'"><xsl:text>[MPa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MetresOfWater'"><xsl:text>[m]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'NewtonPerSquareMeter'"><xsl:text>[N/m2]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Pascal'"><xsl:text>[Pa]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Psi'"><xsl:text>[psi]</xsl:text></xsl:when>
		<!-- otherwise -->
		<xsl:otherwise><xsl:text>[?]</xsl:text></xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
