<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">

<!-- Localised settings for numbers -->
<xsl:decimal-format name="en" decimal-separator="." grouping-separator="," NaN="&#60;Null&#62;"/>
<xsl:decimal-format name="de" decimal-separator="," grouping-separator="." NaN="&#60;Null&#62;"/>

<!-- Reference to the external document with all data -->
<xsl:variable name="EPANET" select="document('EPANETModel.xml')"/>

<xsl:template match="/">
	<html>
		<head>
			<title>Rohre</title>
			<!-- Reference to the external stripes script -->
			<script src="stripes.js" type="text/javascript">
			</script>
		</head>
		
		<!-- Reference to the external style sheet -->
		<link rel="stylesheet" type="text/css"  href="default.css"/>
		
		<body onload="stripe('tabelle', '#ffffff', '#96c3e3')">

			<div id="firmablock">
				<xsl:for-each select="document('Unternehmen.xml')/name/zeile">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</div>
			
			<div id="projektblock">
				<xsl:for-each select="document('Projekt.xml')/titel/zeile">
					<p>
						<xsl:value-of select="."/>
					</p>
				</xsl:for-each>
			</div>

			<h1>Rohre</h1>

			<table id="tabelle" border="0" cellpadding="0" cellspacing="0" summary="">

			<!-- Custom text, e.g. company name, project name
			     In order to make custom text visible, remove: display:none  -->
			<caption style="text-align:left; display:none">Custom Text</caption>

			<colgroup>
				<!--  Column width and column alignment -->
				<col width="90px"/>		<!-- Rohr ID -->
				<col width="120px"/>	<!-- Beschreibung -->
				<col width="90px"/>		<!-- Von Knoten -->
				<col width="90px"/>		<!-- Nach Knoten -->
				<col width="70px" style="text-align: right;"/>	<!-- Durchmesser -->
				<col width="70px" style="text-align: right;"/>	<!-- Lnge -->
				<col width="70px" style="text-align: right;"/>	<!-- Rauhigkeit -->
			</colgroup>
			<thead>
				<tr>
					<!-- Column headers with units -->
					<xsl:for-each select="$EPANET/mu/Group[@Name='mw_Pipe']/Metadata">
					<th>
						Rohr ID
					</th>
					<th>
						Beschreibung
					</th>
					<th>
						Von<br />
						Knoten
					</th>
					<th>
						Nach<br />
						Knoten
					</th>
					<th>
						Durch-<br />
						messer<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Field[@Name='Diameter']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Lnge<br />
						<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Field[@Name='L']/@Unit"/></xsl:call-template>
					</th>
					<th>
						Rauhig-<br />
						keit<br />
						<xsl:call-template name="ChooseUnitAbbr"><xsl:with-param name="UnitString" select="Field[@Name='RCoeff']/@Unit"/></xsl:call-template>
					</th>
					</xsl:for-each>
				</tr>
			</thead>
			<xsl:for-each select="$EPANET/mu/Group[@Name='mw_Pipe']/Rows/R">
				<xsl:sort select="@MUID"/>
				<tr>
					<!-- Data within each row including number format -->
					<td><xsl:value-of select="@MUID"/></td>
					<td><xsl:value-of select="@Description"/></td>
					<td><xsl:value-of select="@_FromNodeID"/></td>
					<td><xsl:value-of select="@_ToNodeID"/></td>
					<td><xsl:value-of select="format-number(@Diameter,'0','de')"/></td>
					<td><xsl:value-of select="format-number(@L,'#.##0,0','de')"/></td>
					<td><xsl:value-of select="format-number(@RCoeff,'0,0','de')"/></td>
				</tr>
			</xsl:for-each>
			</table>

			<!-- Some comment
			     In order to make custom text visible, remove: display:none -->
			<p style="font-size: 9pt; margin-top: 5px; display:none"></p>
		</body>
	</html>

</xsl:template>


<!-- Lookup table for unit abbreviations -->
<xsl:template name="ChooseUnitAbbr">
	<xsl:param name="UnitString"/>
	<xsl:choose>
		<!-- Length -->
		<xsl:when test="$UnitString = 'CentiMeter'"><xsl:text>[cm]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Feet'"><xsl:text>[ft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Inch'"><xsl:text>[in]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'KiloMeter'"><xsl:text>[km]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Meter'"><xsl:text>[m]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Mile'"><xsl:text>[mi]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliFeet'"><xsl:text>[mft]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'MilliMeter'"><xsl:text>[mm]</xsl:text></xsl:when>
		<xsl:when test="$UnitString = 'Yard'"><xsl:text>[yd]</xsl:text></xsl:when>
		<!-- otherwise -->
		<xsl:otherwise><xsl:text>[?]</xsl:text></xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>